@@ -1,4 +1,5 @@
 """Gracefully manage your API interactions"""
+import logging
 
 from . import exceptions
 from ._core import Gracy, graceful
@@ -13,8 +14,11 @@ from ._models import (
     LogLevel,
     ThrottleRule,
 )
+from ._reports._models import GracyAggregatedRequest, GracyAggregatedTotal, GracyReport
 
-__version__ = "1.3.0"
+logging.basicConfig(level=logging.INFO, format="%(asctime)s %(message)s")
+
+__version__ = "1.4.0"
 
 __all__ = [
     "exceptions",
@@ -31,4 +35,8 @@ __all__ = [
     "ThrottleRule",
     "GracyConfig",
     "DEFAULT_CONFIG",
+    # Reports
+    "GracyReport",
+    "GracyAggregatedTotal",
+    "GracyAggregatedRequest",
 ]
