@@ -10,7 +10,7 @@ import httpx
 from ._configs import custom_config_context, custom_gracy_config
 from ._loggers import (
     DefaultLogMessage,
-    process_log,
+    process_log_after_request,
     process_log_before_request,
     process_log_retry,
     process_log_throttle,
@@ -31,7 +31,8 @@ from ._models import (
     ThrottleController,
     Unset,
 )
-from ._reports import GracyReport
+from ._reports._builders import ReportBuilder
+from ._reports._printers import PRINTERS, print_report
 from .exceptions import NonOkResponse, UnexpectedResponse
 
 
@@ -80,7 +81,7 @@ async def _gracefully_throttle(controller: ThrottleController, request_context:
 
 
 async def _gracefully_retry(
-    report: GracyReport,
+    report: ReportBuilder,
     throttle_controller: ThrottleController,
     request: GracefulRequest,
     request_context: GracyRequestContext,
@@ -146,7 +147,7 @@ def _check_allowed(active_config: GracyConfig, result: httpx.Response) -> bool:
 
 
 async def _gracify(
-    report: GracyReport,
+    report: ReportBuilder,
     throttle_controller: ThrottleController,
     request: GracefulRequest,
     request_context: GracyRequestContext,
@@ -162,7 +163,7 @@ async def _gracify(
     report.track(request_context, result)
 
     if active_config.log_response and isinstance(active_config.log_response, LogEvent):
-        process_log(active_config.log_response, DefaultLogMessage.AFTER, request_context, result)
+        process_log_after_request(active_config.log_response, DefaultLogMessage.AFTER, request_context, result)
 
     strict_pass = _check_strictness(active_config, result)
     if strict_pass is False:
@@ -181,7 +182,7 @@ async def _gracify(
 
         if not retry_result or retry_result.failed:
             if active_config.log_errors and isinstance(active_config.log_errors, LogEvent):
-                process_log(active_config.log_errors, DefaultLogMessage.ERRORS, request_context, result)
+                process_log_after_request(active_config.log_errors, DefaultLogMessage.ERRORS, request_context, result)
 
             if isinstance(active_config.retry, GracefulRetry) and active_config.retry.behavior == "pass":
                 must_break = False
@@ -205,7 +206,7 @@ async def _gracify(
 
         if not retry_result or retry_result.failed:
             if isinstance(active_config.log_errors, LogEvent):
-                process_log(active_config.log_errors, DefaultLogMessage.ERRORS, request_context, result)
+                process_log_after_request(active_config.log_errors, DefaultLogMessage.ERRORS, request_context, result)
 
             if isinstance(active_config.retry, GracefulRetry) and active_config.retry.behavior == "pass":
                 must_break = False
@@ -233,7 +234,7 @@ class Gracy(Generic[Endpoint]):
     inheritance.
     """
 
-    _report: GracyReport = GracyReport()
+    _reporter: ReportBuilder = ReportBuilder()
     _throttle_controller: ThrottleController = ThrottleController()
 
     class Config:
@@ -268,7 +269,7 @@ class Gracy(Generic[Endpoint]):
         )
 
         graceful_request = _gracify(
-            Gracy._report,
+            Gracy._reporter,
             Gracy._throttle_controller,
             GracefulRequest(
                 self._client.request,
@@ -346,8 +347,13 @@ class Gracy(Generic[Endpoint]):
         return await self._request("OPTIONS", endpoint, endpoint_args, *args, **kwargs)
 
     @classmethod
-    def report_status(cls):
-        cls._report.print(cls._throttle_controller)
+    def get_report(cls):
+        return cls._reporter.build(cls._throttle_controller)
+
+    @classmethod
+    def report_status(cls, printer: PRINTERS):
+        report = cls.get_report()
+        print_report(report, printer)
 
 
 def graceful(
